# Copyright (C) 2021 Taavi Väänänen
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
import os.path

import yaml
from flask import Flask, Response, jsonify, render_template, request

from preseedd.metadata import get_all_host_data, locate_mac

app = Flask(
    __name__,
    template_folder=os.path.join(
        os.path.dirname(os.path.realpath(__file__)), "templates"
    ),
)


with open(
    os.environ.get("PRESEEDD_CONFIG_PATH", "/etc/preseedd.yaml"), "r"
) as config_file:
    app.config.update(yaml.safe_load(config_file))


@app.route("/preseed.cfg")
def preseed():
    if "mac" in request.args:
        mac = request.args["mac"]
        generate_password = False
    else:
        mac = locate_mac(request.remote_addr)
        generate_password = True

    data = render_template(
        "preseed.cfg.j2",
        **get_all_host_data(mac=mac, generate_password=generate_password)
    )
    return Response(data, content_type="text/plain")


@app.route("/preseedd/get-data")
def get_data():
    if "mac" in request.args:
        mac = request.args["mac"]
    elif "ip" in request.args:
        mac = locate_mac(request.args["ip"])
    else:
        return "ip or mac required", 400

    return jsonify(get_all_host_data(mac))


@app.route("/healthz")
def healthz():
    return Response("OK", content_type="text/plain")


if __name__ == "__main__":
    app.run()
